@@ -59,7 +59,7 @@ class AWSAthenaOperator(BaseOperator):
     template_ext = ('.sql',)
     template_fields_renderers = {"query": "sql"}
 
-    def __init__(  # pylint: disable=too-many-arguments
+    def __init__(
         self,
         *,
         query: str,
@@ -131,7 +131,7 @@ class AWSAthenaOperator(BaseOperator):
             http_status_code = None
             try:
                 http_status_code = response['ResponseMetadata']['HTTPStatusCode']
-            except Exception as ex:  # pylint: disable=broad-except
+            except Exception as ex:
                 self.log.error('Exception while cancelling query: %s', ex)
             finally:
                 if http_status_code is None or http_status_code != 200:
