@@ -99,7 +99,7 @@ class AwsBatchOperator(BaseOperator):
         "overrides",
         "parameters",
     )
-    template_fields_renderers = {"overrides": "py", "parameters": "py"}
+    template_fields_renderers = {"overrides": "json", "parameters": "json"}
 
     def __init__(
         self,
@@ -118,7 +118,7 @@ class AwsBatchOperator(BaseOperator):
         region_name: Optional[str] = None,
         tags: Optional[dict] = None,
         **kwargs,
-    ):  # pylint: disable=too-many-arguments
+    ):
 
         BaseOperator.__init__(self, **kwargs)
         self.job_id = job_id
@@ -150,7 +150,7 @@ class AwsBatchOperator(BaseOperator):
         response = self.hook.client.terminate_job(jobId=self.job_id, reason="Task killed by the user")
         self.log.info("AWS Batch job (%s) terminated: %s", self.job_id, response)
 
-    def submit_job(self, context: Dict):  # pylint: disable=unused-argument
+    def submit_job(self, context: Dict):
         """
         Submit an AWS Batch job
 
@@ -176,29 +176,26 @@ class AwsBatchOperator(BaseOperator):
             self.job_id = response["jobId"]
 
             self.log.info("AWS Batch job (%s) started: %s", self.job_id, response)
-
         except Exception as e:
             self.log.error("AWS Batch job (%s) failed submission", self.job_id)
             raise AirflowException(e)
 
-    def monitor_job(self, context: Dict):  # pylint: disable=unused-argument
+    def monitor_job(self, context: Dict):
         """
         Monitor an AWS Batch job
+        monitor_job can raise an exception or an AirflowTaskTimeout can be raised if execution_timeout
+        is given while creating the task. These exceptions should be handled in taskinstance.py
+        instead of here like it was previously done
 
         :raises: AirflowException
         """
         if not self.job_id:
             raise AirflowException('AWS Batch job - job_id was not found')
 
-        try:
-            if self.waiters:
-                self.waiters.wait_for_job(self.job_id)
-            else:
-                self.hook.wait_for_job(self.job_id)
+        if self.waiters:
+            self.waiters.wait_for_job(self.job_id)
+        else:
+            self.hook.wait_for_job(self.job_id)
 
-            self.hook.check_job_success(self.job_id)
-            self.log.info("AWS Batch job (%s) succeeded", self.job_id)
-
-        except Exception as e:
-            self.log.error("AWS Batch job (%s) failed monitoring", self.job_id)
-            raise AirflowException(e)
+        self.hook.check_job_success(self.job_id)
+        self.log.info("AWS Batch job (%s) succeeded", self.job_id)
