@@ -118,10 +118,10 @@ class S3ToRedshiftOperator(BaseOperator):
         copy_statement = self._build_copy_query(credentials_block, copy_options)
 
         if self.truncate_table:
-            truncate_statement = f'TRUNCATE TABLE {self.schema}.{self.table};'
+            delete_statement = f'DELETE FROM {self.schema}.{self.table};'
             sql = f"""
             BEGIN;
-            {truncate_statement}
+            {delete_statement}
             {copy_statement}
             COMMIT
             """
