@@ -28,6 +28,10 @@ class SFTPToS3Operator(BaseOperator):
     This operator enables the transferring of files from a SFTP server to
     Amazon S3.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:SFTPToS3Operator`
+
     :param sftp_conn_id: The sftp connection id. The name or identifier for
         establishing a connection to the SFTP server.
     :type sftp_conn_id: str
